@@ -46,6 +46,7 @@ API_PATH = {
     "emoji_delete":            "api/v1/{subreddit}/emoji/{emoji_name}",
     "emoji_lease":             "api/v1/{subreddit}/emoji_asset_upload_s3.json",
     "emoji_list":              "api/v1/{subreddit}/emojis/all",
+    "emoji_update":            "api/v1/{subreddit}/emoji_permissions",
     "emoji_upload":            "api/v1/{subreddit}/emoji.json",
     "flair":                   "r/{subreddit}/api/flair/",
     "flairconfig":             "r/{subreddit}/api/flairconfig/",
@@ -128,6 +129,7 @@ API_PATH = {
     "my_moderator":            "subreddits/mine/moderator/",
     "my_multireddits":         "api/multi/mine/",
     "my_subreddits":           "subreddits/mine/subscriber/",
+    "post_requirements":       "api/v1/{subreddit}/post_requirements",
     "preferences":             "api/v1/me/prefs",
     "quarantine_opt_in":       "api/quarantine_optin",
     "quarantine_opt_out":      "api/quarantine_optout",
@@ -147,6 +149,7 @@ API_PATH = {
     "sent":                    "message/sent/",
     "set_original_content":    "api/set_original_content",
     "setpermissions":          "r/{subreddit}/api/setpermissions/",
+    "show_comment":            "api/show_comment",
     "site_admin":              "api/site_admin/",
     "spoiler":                 "api/spoiler/",
     "sticky_submission":       "api/set_subreddit_sticky/",
