@@ -8,7 +8,7 @@ from .list.trophy import TrophyList
 from .listing.domain import DomainListing
 from .listing.generator import ListingGenerator
 from .listing.listing import Listing
-from .modaction import ModAction
+from .mod_action import ModAction
 from .preferences import Preferences
 from .reddit.collections import Collection
 from .reddit.comment import Comment
@@ -19,6 +19,7 @@ from .reddit.modmail import ModmailAction, ModmailConversation, ModmailMessage
 from .reddit.more import MoreComments
 from .reddit.multi import Multireddit
 from .reddit.redditor import Redditor
+from .reddit.removal_reasons import RemovalReason
 from .reddit.submission import Submission
 from .reddit.subreddit import Subreddit
 from .reddit.widgets import (
@@ -36,9 +37,9 @@ from .reddit.widgets import (
     ModeratorsWidget,
     PostFlairWidget,
     RulesWidget,
+    Submenu,
     SubredditWidgets,
     SubredditWidgetsModeration,
-    Submenu,
     TextArea,
     Widget,
     WidgetModeration,
@@ -46,7 +47,6 @@ from .reddit.widgets import (
 from .reddit.wikipage import WikiPage
 from .redditors import Redditors
 from .stylesheet import Stylesheet
-
 from .subreddits import Subreddits
 from .trophy import Trophy
 from .user import User
