@@ -2,6 +2,7 @@
 from heapq import heappop, heappush
 from typing import List, Optional, TypeVar, Union
 
+from ..exceptions import DuplicateReplaceException
 from .reddit.more import MoreComments
 
 Comment = TypeVar("Comment")
@@ -72,12 +73,16 @@ class CommentForest:
         return len(self._comments)
 
     def _insert_comment(self, comment):
-        assert comment.name not in self._submission._comments_by_id
+        if comment.name in self._submission._comments_by_id:
+            raise DuplicateReplaceException
         comment.submission = self._submission
         if isinstance(comment, MoreComments) or comment.is_root:
             self._comments.append(comment)
         else:
-            assert comment.parent_id in self._submission._comments_by_id
+            assert comment.parent_id in self._submission._comments_by_id, (
+                "PRAW Error occured. Please file a bug report and include "
+                "the code that caused the error."
+            )
             parent = self._submission._comments_by_id[comment.parent_id]
             parent.replies._comments.append(comment)
 
@@ -153,6 +158,10 @@ class CommentForest:
                              print('Handling replace_more exception')
                              sleep(1)
 
+        .. warning:: If this method is called, and the comments are refreshed,
+            calling this method again will result in a
+            :class:`.DuplicateReplaceException`.
+
         """
         remaining = limit
         more_comments = self._gather_more_comments(self._comments)
