@@ -2,7 +2,7 @@
 from typing import Any, Dict, Optional, TypeVar, Union
 
 from ...const import API_PATH
-from ...exceptions import ClientException
+from ...exceptions import ClientException, InvalidURL
 from ...util.cache import cachedproperty
 from ..comment_forest import CommentForest
 from .base import RedditBase
@@ -45,9 +45,9 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
     ``is_submitter``        Whether or not the comment author is also the
                             author of the submission.
     ``link_id``             The submission ID that the comment belongs to.
-    ``parent_id``           The ID of the parent comment. If it is a top-level
-                            comment, this returns the submission ID instead
-                            (prefixed with 't3').
+    ``parent_id``           The ID of the parent comment (prefixed with ``t1_``).
+                            If it is a top-level comment, this returns the
+                            submission ID instead (prefixed with ``t3_``).
     ``permalink``           A permalink for the comment. Comment objects from
                             the inbox have a ``context`` attribute instead.
     ``replies``             Provides an instance of :class:`.CommentForest`.
@@ -77,10 +77,10 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
         try:
             comment_index = parts.index("comments")
         except ValueError:
-            raise ClientException("Invalid URL: {}".format(url))
+            raise InvalidURL(url)
 
         if len(parts) - 4 != comment_index:
-            raise ClientException("Invalid URL: {}".format(url))
+            raise InvalidURL(url)
         return parts[-1]
 
     @property
@@ -96,7 +96,16 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
 
     @cachedproperty
     def mod(self) -> _CommentModeration:
-        """Provide an instance of :class:`.CommentModeration`."""
+        """Provide an instance of :class:`.CommentModeration`.
+
+        Example usage:
+
+        .. code-block:: python
+
+            comment = reddit.comment('dkk4qjd')
+            comment.mod.approve()
+
+        """
         return CommentModeration(self)
 
     @property
@@ -116,6 +125,10 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
            comment.refresh()
            replies = comment.replies
 
+        .. note:: The appropriate values for ``reply_sort`` include
+           ``confidence``, ``controversial``, ``new``, ``old``, ``q&a``,
+           and ``top``.
+
         """
         if isinstance(self._replies, list):
             self._replies = CommentForest(self.submission, self._replies)
@@ -147,7 +160,7 @@ class Comment(InboxableMixin, UserContentMixin, FullnameMixin, RedditBase):
         _data: Optional[Dict[str, Any]] = None,
     ):
         """Construct an instance of the Comment object."""
-        if [id, url, _data].count(None) != 2:
+        if (id, url, _data).count(None) != 2:
             raise TypeError(
                 "Exactly one of `id`, `url`, or `_data` must be provided."
             )
@@ -345,3 +358,18 @@ class CommentModeration(ThingModerationMixin):
 
         """
         self.thing = comment
+
+    def show(self):
+        """Uncollapse a :class:`~.Comment` that has been collapsed by Crowd Control.
+
+        Example usage:
+
+        .. code-block:: python
+
+           # lock a comment:
+           comment = reddit.comment('dkk4qjd')
+           comment.mod.show()
+        """
+        url = API_PATH["show_comment"]
+
+        self.thing._reddit.post(url, data={"id": self.thing.fullname})
