@@ -90,7 +90,7 @@ class ThingModerationMixin:
            submission = reddit.submission(id='5or86n')
            submission.mod.distinguish(how='no')
 
-        See also :meth:`~.undistinguish`
+        .. seealso:: :meth:`~.undistinguish`
 
         """
         data = {"how": how, "id": self.thing.fullname}
@@ -117,7 +117,7 @@ class ThingModerationMixin:
            submission = reddit.submission(id='5or86n')
            submission.mod.ignore_reports()
 
-        See also :meth:`~.unignore_reports`
+        .. seealso:: :meth:`~.unignore_reports`
 
         """
         self.thing._reddit.post(
@@ -138,7 +138,7 @@ class ThingModerationMixin:
            submission = reddit.submission(id='5or86n')
            submission.mod.lock()
 
-        See also :meth:`~.unlock`
+        .. seealso:: :meth:`~.unlock`
 
         """
         self.thing._reddit.post(
@@ -188,7 +188,8 @@ class ThingModerationMixin:
         .. warning:: The object has to be removed before giving it a removal
             reason. Remove the object with :meth:`.remove`. Trying to add a
             removal reason without removing the object will result in
-            ``prawcore.exceptions.BadRequest`` being thrown.
+            :class:`.RedditAPIException` being thrown with an ``INVALID_ID``
+            error_type.
 
         Reddit adds human-readable information about the object to the message.
 
@@ -234,7 +235,7 @@ class ThingModerationMixin:
            submission = reddit.submission(id='5or86n')
            submission.mod.undistinguish()
 
-        See also :meth:`~.distinguish`
+        .. seealso:: :meth:`~.distinguish`
 
         """
         self.distinguish(how="no")
@@ -257,7 +258,7 @@ class ThingModerationMixin:
            submission = reddit.submission(id='5or86n')
            submission.mod.unignore_reports()
 
-        See also :meth:`~.ignore_reports`
+        .. seealso:: :meth:`~.ignore_reports`
 
         """
         self.thing._reddit.post(
@@ -269,6 +270,8 @@ class ThingModerationMixin:
 
         Example usage:
 
+        .. code-block:: python
+
            # unlock a comment:
            comment = reddit.comment('dkk4qjd')
            comment.mod.unlock()
@@ -276,7 +279,7 @@ class ThingModerationMixin:
            submission = reddit.submission(id='5or86n')
            submission.mod.unlock()
 
-        See also :meth:`~.lock`
+        .. seealso:: :meth:`~.lock`
 
         """
         self.thing._reddit.post(
