@@ -5,7 +5,7 @@ from ....const import API_PATH
 class ReplyableMixin:
     """Interface for RedditBase classes that can be replied to."""
 
-    def reply(self, body):
+    def reply(self, body: str):
         """Reply to the object.
 
         :param body: The Markdown formatted content for a comment.
@@ -18,6 +18,10 @@ class ReplyableMixin:
         comment will be sucessfully created on Reddit and can be retried
         by drawing the comment from the user's comment history.
 
+        .. note:: Some items, such as locked submissions/comments or
+            non-replyable messages will throw ``prawcore.exceptions.Forbidden``
+            when attempting to reply to them.
+
         Example usage:
 
         .. code-block:: python
