@@ -1,8 +1,13 @@
 """Provide models for new modmail."""
+from typing import Any, Dict, List, Optional, TypeVar
+
 from ...const import API_PATH
 from ...util import snake_case_keys
 from .base import RedditBase
 
+_ModmailConversation = TypeVar("_ModmailConversation")
+Reddit = TypeVar("Reddit")
+
 
 class ModmailConversation(RedditBase):
     """A class for modmail conversations.
@@ -90,7 +95,7 @@ class ModmailConversation(RedditBase):
 
     @classmethod
     def parse(  # pylint: disable=arguments-differ
-        cls, data, reddit, convert_objects=True
+        cls, data: Dict[str, Any], reddit: Reddit, convert_objects: bool = True
     ):
         """Return an instance of ModmailConversation from ``data``.
 
@@ -125,10 +130,10 @@ class ModmailConversation(RedditBase):
 
     def __init__(
         self,
-        reddit,
-        id=None,  # pylint: disable=redefined-builtin
-        mark_read=False,
-        _data=None,
+        reddit: Reddit,
+        id: Optional[str] = None,  # pylint: disable=redefined-builtin
+        mark_read: bool = False,
+        _data: Optional[Dict[str, Any]] = None,
     ):
         """Construct an instance of the ModmailConversation object.
 
@@ -136,12 +141,12 @@ class ModmailConversation(RedditBase):
             (default: False).
 
         """
-        super(ModmailConversation, self).__init__(reddit, _data=_data)
+        super().__init__(reddit, _data=_data)
         if bool(id) == bool(_data):
             raise TypeError("Either `id` or `_data` must be provided.")
 
         if id:
-            self.id = id  # pylint: disable=invalid-name
+            self.id = id
 
         self._info_params = {"markRead": True} if mark_read else None
 
@@ -167,9 +172,9 @@ class ModmailConversation(RedditBase):
     def archive(self):
         """Archive the conversation.
 
-        Example:
+        For example:
 
-        .. code:: python
+        .. code-block:: python
 
            reddit.subreddit('redditdev').modmail('2gmz').archive()
 
@@ -179,9 +184,9 @@ class ModmailConversation(RedditBase):
     def highlight(self):
         """Highlight the conversation.
 
-        Example:
+        For example:
 
-        .. code:: python
+        .. code-block:: python
 
            reddit.subreddit('redditdev').modmail('2gmz').highlight()
 
@@ -191,9 +196,9 @@ class ModmailConversation(RedditBase):
     def mute(self):
         """Mute the non-mod user associated with the conversation.
 
-        Example:
+        For example:
 
-        .. code:: python
+        .. code-block:: python
 
            reddit.subreddit('redditdev').modmail('2gmz').mute()
 
@@ -202,7 +207,9 @@ class ModmailConversation(RedditBase):
             "POST", API_PATH["modmail_mute"].format(id=self.id)
         )
 
-    def read(self, other_conversations=None):  # noqa: D207, D301
+    def read(
+        self, other_conversations: Optional[List[_ModmailConversation]] = None
+    ):  # noqa: D207, D301
         """Mark the conversation(s) as read.
 
         :param other_conversations: A list of other conversations to mark
@@ -211,12 +218,12 @@ class ModmailConversation(RedditBase):
         For example, to mark the conversation as read along with other recent
         conversations from the same user:
 
-        .. code:: python
+        .. code-block:: python
 
            subreddit = reddit.subreddit('redditdev')
            conversation = subreddit.modmail.conversation('2gmz')
-           conversation.read(\
-other_conversations=conversation.user.recent_convos)
+           conversation.read(
+                            other_conversations=conversation.user.recent_convos)
 
         """
         data = {
@@ -226,10 +233,12 @@ other_conversations=conversation.user.recent_convos)
         }
         self._reddit.post(API_PATH["modmail_read"], data=data)
 
-    def reply(self, body, author_hidden=False, internal=False):
+    def reply(
+        self, body: str, author_hidden: bool = False, internal: bool = False
+    ):
         """Reply to the conversation.
 
-        :param body: The markdown formatted content for a message.
+        :param body: The Markdown formatted content for a message.
         :param author_hidden: When True, author is hidden from non-moderators
             (default: False).
         :param internal: When True, message is a private moderator note,
@@ -239,14 +248,14 @@ other_conversations=conversation.user.recent_convos)
 
         For example, to reply to the non-mod user while hiding your username:
 
-        .. code:: python
+        .. code-block:: python
 
            conversation = reddit.subreddit('redditdev').modmail('2gmz')
            conversation.reply('Message body', author_hidden=True)
 
         To create a private moderator note on the conversation:
 
-        .. code:: python
+        .. code-block:: python
 
            conversation.reply('Message body', internal=True)
 
@@ -266,9 +275,9 @@ other_conversations=conversation.user.recent_convos)
     def unarchive(self):
         """Unarchive the conversation.
 
-        Example:
+        For example:
 
-        .. code:: python
+        .. code-block:: python
 
            reddit.subreddit('redditdev').modmail('2gmz').unarchive()
 
@@ -278,9 +287,9 @@ other_conversations=conversation.user.recent_convos)
     def unhighlight(self):
         """Un-highlight the conversation.
 
-        Example:
+        For example:
 
-        .. code:: python
+        .. code-block:: python
 
            reddit.subreddit('redditdev').modmail('2gmz').unhighlight()
 
@@ -292,9 +301,9 @@ other_conversations=conversation.user.recent_convos)
     def unmute(self):
         """Unmute the non-mod user associated with the conversation.
 
-        Example:
+        For example:
 
-        .. code:: python
+        .. code-block:: python
 
            reddit.subreddit('redditdev').modmail('2gmz').unmute()
 
@@ -303,7 +312,9 @@ other_conversations=conversation.user.recent_convos)
             "POST", API_PATH["modmail_unmute"].format(id=self.id)
         )
 
-    def unread(self, other_conversations=None):  # noqa: D207, D301
+    def unread(
+        self, other_conversations: Optional[List[_ModmailConversation]] = None
+    ):  # noqa: D207, D301
         """Mark the conversation(s) as unread.
 
         :param other_conversations: A list of other conversations to mark
@@ -312,7 +323,7 @@ other_conversations=conversation.user.recent_convos)
         For example, to mark the conversation as unread along with other recent
         conversations from the same user:
 
-        .. code:: python
+        .. code-block:: python
 
            subreddit = reddit.subreddit('redditdev')
            conversation = subreddit.modmail.conversation('2gmz')
@@ -334,11 +345,11 @@ class ModmailObject(RedditBase):
     AUTHOR_ATTRIBUTE = "author"
     STR_FIELD = "id"
 
-    def __setattr__(self, attribute, value):
+    def __setattr__(self, attribute: str, value: Any):
         """Objectify the AUTHOR_ATTRIBUTE attribute."""
         if attribute == self.AUTHOR_ATTRIBUTE:
             value = self._reddit._objector.objectify(value)
-        super(ModmailObject, self).__setattr__(attribute, value)
+        super().__setattr__(attribute, value)
 
 
 class ModmailAction(ModmailObject):
