@@ -22,11 +22,11 @@ class MoreComments(PRAWBase):
 
     def __eq__(self, other: Union[str, _MoreComments]) -> bool:
         """Return True if these MoreComments instances are the same."""
-        return (
-            isinstance(other, self.__class__)
-            and self.count == other.count
-            and self.children == other.children
-        )
+        if isinstance(other, self.__class__):
+            return (
+                self.count == other.count and self.children == other.children
+            )
+        return super().__eq__(other)
 
     def __lt__(self, other: _MoreComments) -> bool:
         """Provide a sort order on the MoreComments object."""
@@ -45,7 +45,7 @@ class MoreComments(PRAWBase):
         )
 
     def _continue_comments(self, update):
-        assert not self.children
+        assert not self.children, "Please file a bug report with PRAW."
         parent = self._load_comment(self.parent_id.split("_", 1)[1])
         self._comments = parent.replies
         if update:
@@ -64,7 +64,9 @@ class MoreComments(PRAWBase):
                 "sort": self.submission.comment_sort,
             },
         )
-        assert len(comments.children) == 1
+        assert (
+            len(comments.children) == 1
+        ), "Please file a bug report with PRAW."
         return comments.children[0]
 
     def comments(self, update: bool = True) -> List[Comment]:
@@ -72,7 +74,7 @@ class MoreComments(PRAWBase):
         if self._comments is None:
             if self.count == 0:  # Handle 'continue this thread'
                 return self._continue_comments(update)
-            assert self.children
+            assert self.children, "Please file a bug report with PRAW."
             data = {
                 "children": ",".join(self.children),
                 "link_id": self.submission.fullname,
