@@ -32,6 +32,12 @@ class Redditor(
     guarantee that these attributes will always be present, nor is this list
     comprehensive in any way.
 
+    .. note:: Shadowbanned accounts are treated the same as non-existent
+        accounts, meaning that they will not have any attributes.
+
+    .. note:: Suspended/banned accounts will only return the ``name`` and
+        ``is_suspended`` attributes.
+
     ==================================== ======================================
     Attribute                            Description
     ==================================== ======================================
@@ -53,6 +59,8 @@ class Redditor(
                                          subreddits.
     ``is_gold``                          Whether or not the Redditor has active
                                          Reddit Premium status.
+    ``is_suspended``                     Whether or not the Redditor is
+                                         currently suspended.
     ``link_karma``                       The link karma for the Redditor.
     ``name``                             The Redditor's username.
     ``subreddit``                        If the Redditor has created a
@@ -132,7 +140,7 @@ class Redditor(
         Exactly one of ``name``, ``fullname`` or ``_data`` must be provided.
 
         """
-        if [name, fullname, _data].count(None) != 2:
+        if (name, fullname, _data).count(None) != 2:
             raise TypeError(
                 "Exactly one of `name`, `fullname`, or `_data` must be "
                 "provided."
@@ -175,7 +183,15 @@ class Redditor(
         self._reddit.request(method, url, data=dumps(data))
 
     def block(self):
-        """Block the Redditor."""
+        """Block the Redditor.
+
+        For example, to block Redditor ``spez``:
+
+        .. code-block:: python
+
+            reddit.redditor("spez").block()
+
+        """
         self._reddit.post(
             API_PATH["block_user"], params={"account_id": self.fullname}
         )
@@ -188,6 +204,18 @@ class Redditor(
 
         Calling this method subsequent times will update the note.
 
+        For example, to friend Redditor ``spez``:
+
+        .. code-block:: python
+
+            reddit.redditor("spez").friend()
+
+        To add a note to the friendship (requires Reddit Premium):
+
+        .. code-block:: python
+
+            reddit.redditor("spez").friend(note="My favorite admin")
+
         """
         self._friend("PUT", data={"note": note} if note else {})
 
@@ -197,6 +225,13 @@ class Redditor(
         :returns: A :class:`.Redditor` instance with fields ``date``, ``id``,
             and possibly ``note`` if the authenticated user has Reddit Premium.
 
+        For example, to get the friendship information of Redditor ``spez``:
+
+        .. code-block:: python
+
+            info = reddit.redditor("spez").friend_info
+            friend_data = info.date
+
         """
         return self._reddit.get(API_PATH["friend_v1"].format(user=self))
 
@@ -206,6 +241,12 @@ class Redditor(
         :param months: Specifies the number of months to gild up to 36
             (default: 1).
 
+        For example, to gild Redditor ``spez`` for 1 month:
+
+        .. code-block:: python
+
+            reddit.redditor("spez").gild(months=1)
+
         """
         if months < 1 or months > 36:
             raise TypeError("months must be between 1 and 36")
@@ -243,7 +284,16 @@ class Redditor(
             return subreddits
 
     def multireddits(self) -> List[Multireddit]:
-        """Return a list of the redditor's public multireddits."""
+        """Return a list of the redditor's public multireddits.
+
+        For example, to to get Redditor ``spez``'s multireddits:
+
+        .. code-block:: python
+
+            multireddits = reddit.redditor("spez").multireddits()
+
+
+        """
         return self._reddit.get(API_PATH["multireddit_user"].format(user=self))
 
     def trophies(self) -> List[Trophy]:
@@ -252,7 +302,7 @@ class Redditor(
         :returns: A ``list`` of :class:`~praw.models.Trophy` objects.
             Return ``[]`` if the redditor has no trophy.
 
-        Raise ``prawcore.exceptions.BadRequest`` if the redditor doesn't exist.
+        :raises: :class:`.RedditAPIException` if the redditor doesn't exist.
 
         Usage:
 
@@ -266,7 +316,15 @@ class Redditor(
         return list(self._reddit.get(API_PATH["trophies"].format(user=self)))
 
     def unblock(self):
-        """Unblock the Redditor."""
+        """Unblock the Redditor.
+
+        For example, to unblock Redditor ``spez``:
+
+        .. code-block:: python
+
+            reddit.redditor("spez").unblock()
+
+        """
         data = {
             "container": self._reddit.user.me().fullname,
             "name": str(self),
@@ -276,7 +334,15 @@ class Redditor(
         self._reddit.post(url, data=data)
 
     def unfriend(self):
-        """Unfriend the Redditor."""
+        """Unfriend the Redditor.
+
+        For example, to unfriend Redditor ``spez``:
+
+        .. code-block:: python
+
+            reddit.redditor("spez").unfriend()
+
+        """
         self._friend(method="DELETE", data={"id": str(self)})
 
 
