@@ -2,8 +2,10 @@
 from typing import Any, Dict, List, Optional, TypeVar, Union
 from urllib.parse import urljoin
 
+from prawcore import Conflict
+
 from ...const import API_PATH
-from ...exceptions import ClientException
+from ...exceptions import InvalidURL
 from ...util.cache import cachedproperty
 from ..comment_forest import CommentForest
 from ..listing.listing import Listing
@@ -127,13 +129,20 @@ class SubmissionModeration(ThingModerationMixin):
             data={"id": self.thing.fullname, "state": state},
         )
 
-    def flair(self, text: str = "", css_class: str = ""):
+    def flair(
+        self,
+        text: str = "",
+        css_class: str = "",
+        flair_template_id: Optional[str] = None,
+    ):
         """Set flair for the submission.
 
         :param text: The flair text to associate with the Submission (default:
             '').
         :param css_class: The css class to associate with the flair html
             (default: '').
+        :param flair_template_id: The flair template id to use when flairing
+            (Optional).
 
         This method can only be used by an authenticated user who is a
         moderator of the Submission's Subreddit.
@@ -152,6 +161,11 @@ class SubmissionModeration(ThingModerationMixin):
             "text": text,
         }
         url = API_PATH["flair"].format(subreddit=self.thing.subreddit)
+        if flair_template_id is not None:
+            data["flair_template_id"] = flair_template_id
+            url = API_PATH["select_flair"].format(
+                subreddit=self.thing.subreddit
+            )
         self.thing._reddit.post(url, data=data)
 
     def nsfw(self):
@@ -168,7 +182,7 @@ class SubmissionModeration(ThingModerationMixin):
                                                         selftext='nsfw')
            submission.mod.nsfw()
 
-        See also :meth:`~.sfw`
+        .. seealso:: :meth:`~.sfw`
 
         """
         self.thing._reddit.post(
@@ -191,7 +205,7 @@ class SubmissionModeration(ThingModerationMixin):
                                                         selftext='original')
            submission.mod.set_original_content()
 
-        See also :meth:`.unset_original_content`
+        .. seealso:: :meth:`.unset_original_content`
 
         """
         data = {
@@ -216,7 +230,7 @@ class SubmissionModeration(ThingModerationMixin):
            submission = reddit.submission(id='5or86n')
            submission.mod.sfw()
 
-        See also :meth:`~.nsfw`
+        .. seealso:: :meth:`~.nsfw`
 
         """
         self.thing._reddit.post(
@@ -236,14 +250,16 @@ class SubmissionModeration(ThingModerationMixin):
            submission = reddit.submission(id='5or86n')
            submission.mod.spoiler()
 
-        See also :meth:`~.unspoiler`
+        .. seealso:: :meth:`~.unspoiler`
 
         """
         self.thing._reddit.post(
             API_PATH["spoiler"], data={"id": self.thing.fullname}
         )
 
-    def sticky(self, state: bool = True, bottom: bool = True):
+    def sticky(
+        self, state: bool = True, bottom: bool = True,
+    ):
         """Set the submission's sticky state in its subreddit.
 
         :param state: (boolean) True sets the sticky for the submission, false
@@ -252,7 +268,11 @@ class SubmissionModeration(ThingModerationMixin):
             sticky. If no top sticky exists, this submission will become the
             top sticky regardless (default: True).
 
-        This submission will replace an existing stickied submission if one
+        .. note:: When a submission is stickied two or more times, the Reddit
+            API responds with a 409 error that is raises as a ``Conflict`` by
+            PRAWCore. The method suppresses these ``Conflict`` errors.
+
+        This submission will replace the second stickied submission if one
         exists.
 
         For example:
@@ -266,9 +286,12 @@ class SubmissionModeration(ThingModerationMixin):
         data = {"id": self.thing.fullname, "state": state}
         if not bottom:
             data["num"] = 1
-        return self.thing._reddit.post(
-            API_PATH["sticky_submission"], data=data
-        )
+        try:
+            return self.thing._reddit.post(
+                API_PATH["sticky_submission"], data=data
+            )
+        except Conflict:
+            pass
 
     def suggested_sort(self, sort: str = "blank"):
         """Set the suggested sort for the comments of the submission.
@@ -298,7 +321,7 @@ class SubmissionModeration(ThingModerationMixin):
                                                         selftext='original')
            submission.mod.unset_original_content()
 
-        See also :meth:`.set_original_content`
+        .. seealso:: :meth:`.set_original_content`
 
         """
         data = {
@@ -324,7 +347,7 @@ class SubmissionModeration(ThingModerationMixin):
                                                         selftext='spoiler')
            submission.mod.unspoiler()
 
-        See also :meth:`~.spoiler`
+        .. seealso:: :meth:`~.spoiler`
 
         """
         self.thing._reddit.post(
@@ -398,26 +421,26 @@ class Submission(
 
         :param url: A url to a submission in one of the following formats (http
             urls will also work):
+
             * https://redd.it/2gmzqe
             * https://reddit.com/comments/2gmzqe/
             * https://www.reddit.com/r/redditdev/comments/2gmzqe/praw_https/
 
-        Raise :class:`.ClientException` if URL is not a valid submission URL.
+        :raises: :class:`.InvalidURL` if URL is not a valid submission URL.
 
         """
         parts = RedditBase._url_parts(url)
         if "comments" not in parts:
             submission_id = parts[-1]
             if "r" in parts:
-                raise ClientException(
-                    "Invalid URL (subreddit, "
-                    "not submission): {}".format(url)
+                raise InvalidURL(
+                    url, message="Invalid URL (subreddit, not submission): {}",
                 )
         else:
             submission_id = parts[parts.index("comments") + 1]
 
         if not submission_id.isalnum():
-            raise ClientException("Invalid URL: {}".format(url))
+            raise InvalidURL(url)
         return submission_id
 
     @property
@@ -446,6 +469,10 @@ class Submission(
            submission.comment_sort = 'new'
            comments = submission.comments.list()
 
+        .. note:: The appropriate values for ``comment_sort`` include
+           ``confidence``, ``controversial``, ``new``, ``old``, ``q&a``,
+           and ``top``
+
         See :ref:`extracting_comments` for more on working with a
         :class:`.CommentForest`.
 
@@ -476,7 +503,16 @@ class Submission(
 
     @cachedproperty
     def mod(self) -> SubmissionModeration:
-        """Provide an instance of :class:`.SubmissionModeration`."""
+        """Provide an instance of :class:`.SubmissionModeration`.
+
+        Example usage:
+
+        .. code-block:: python
+
+           submission = reddit.submission(id="8dmv8z")
+           submission.mod.approve()
+
+        """
         return SubmissionModeration(self)
 
     @property
@@ -506,7 +542,7 @@ class Submission(
         Either ``id`` or ``url`` can be provided, but not both.
 
         """
-        if [id, url, _data].count(None) != 2:
+        if (id, url, _data).count(None) != 2:
             raise TypeError(
                 "Exactly one of `id`, `url`, or `_data` must be provided."
             )
@@ -514,7 +550,7 @@ class Submission(
         self.comment_limit = 2048
 
         # Specify the sort order for ``comments``
-        self.comment_sort = "best"
+        self.comment_sort = "confidence"
 
         if id is not None:
             self.id = id
@@ -597,7 +633,7 @@ class Submission(
            submission = reddit.submission(id='5or86n')
            submission.hide()
 
-        See also :meth:`~.unhide`
+        .. seealso:: :meth:`~.unhide`
 
         """
         for submissions in self._chunk(other_submissions, 50):
@@ -617,7 +653,7 @@ class Submission(
            submission = reddit.submission(id='5or86n')
            submission.unhide()
 
-        See also :meth:`~.hide`
+        .. seealso:: :meth:`~.hide`
 
         """
         for submissions in self._chunk(other_submissions, 50):
@@ -663,7 +699,7 @@ class Submission(
            cross_post = submission.crosspost(subreddit="learnprogramming",
                                              send_replies=False)
 
-        See also :meth:`~.hide`
+        .. seealso:: :meth:`~.hide`
 
         """
         if title is None:
