@@ -1,8 +1,12 @@
 """Provide the Reddit class."""
 import configparser
 import os
+import re
+import time
 from itertools import islice
-from typing import IO, Any, Dict, Generator, Optional, Sequence, Type, Union
+from logging import getLogger
+from typing import IO, Any, Dict, Generator, Iterable, Optional, Type, Union
+from warnings import warn
 
 from prawcore import (
     Authorizer,
@@ -15,11 +19,16 @@ from prawcore import (
     UntrustedAuthenticator,
     session,
 )
+from prawcore.exceptions import BadRequest
 
 from . import models
 from .config import Config
 from .const import API_PATH, USER_AGENT_FORMAT, __version__
-from .exceptions import ClientException
+from .exceptions import (
+    ClientException,
+    MissingRequiredAttributeException,
+    RedditAPIException,
+)
 from .objector import Objector
 
 try:
@@ -35,6 +44,8 @@ Redditor = models.Redditor
 Submission = models.Submission
 Subreddit = models.Subreddit
 
+logger = getLogger("praw")
+
 
 class Reddit:
     """The Reddit class provides convenient access to Reddit's API.
@@ -53,6 +64,7 @@ class Reddit:
     """
 
     update_checked = False
+    _ratelimit_regex = re.compile(r"([0-9]{1,2}) (seconds?|minutes?)")
 
     @property
     def _next_unique(self):
@@ -69,7 +81,7 @@ class Reddit:
     def read_only(self, value: bool) -> None:
         """Set or unset the use of the ReadOnlyAuthorizer.
 
-        Raise :class:`ClientException` when attempting to unset ``read_only``
+        :raises: :class:`ClientException` when attempting to unset ``read_only``
         and only the ReadOnlyAuthorizer is available.
 
         """
@@ -83,6 +95,24 @@ class Reddit:
         else:
             self._core = self._authorized_core
 
+    @property
+    def validate_on_submit(self) -> bool:
+        """Get validate_on_submit."""
+        value = self._validate_on_submit
+        if value is False:
+            warn(
+                "Reddit will check for validation on all posts around "
+                "May-June 2020. It is recommended to check for validation"
+                " by setting reddit.validate_on_submit to True.",
+                category=DeprecationWarning,
+                stacklevel=3,
+            )
+        return value
+
+    @validate_on_submit.setter
+    def validate_on_submit(self, val: bool):
+        self._validate_on_submit = val
+
     def __enter__(self):
         """Handle the context manager open."""
         return self
@@ -93,6 +123,7 @@ class Reddit:
     def __init__(
         self,
         site_name: str = None,
+        config_interpolation: Optional[str] = None,
         requestor_class: Optional[Type[Requestor]] = None,
         requestor_kwargs: Dict[str, Any] = None,
         **config_settings: str
@@ -150,10 +181,13 @@ class Reddit:
         self._core = self._authorized_core = self._read_only_core = None
         self._objector = None
         self._unique_counter = 0
+        self._validate_on_submit = False
 
         try:
             config_section = site_name or os.getenv("praw_site") or "DEFAULT"
-            self.config = Config(config_section, **config_settings)
+            self.config = Config(
+                config_section, config_interpolation, **config_settings
+            )
         except configparser.NoSectionError as exc:
             help_message = (
                 "You provided the name of a praw.ini "
@@ -180,9 +214,11 @@ class Reddit:
                 self.config.CONFIG_NOT_SET,
                 None,
             ):
-                raise ClientException(required_message.format(attribute))
+                raise MissingRequiredAttributeException(
+                    required_message.format(attribute)
+                )
         if self.config.client_secret is self.config.CONFIG_NOT_SET:
-            raise ClientException(
+            raise MissingRequiredAttributeException(
                 required_message.format("client_secret")
                 + "\nFor installed applications this value "
                 "must be set to None via a keyword argument "
@@ -284,7 +320,7 @@ class Reddit:
            reddit.subreddit('redditdev')
 
         Note that multiple subreddits can be combined and filtered views of
-        /r/all can also be used just like a subreddit:
+        r/all can also be used just like a subreddit:
 
         .. code-block:: python
 
@@ -451,12 +487,11 @@ class Reddit:
             None).
 
         """
-        data = self.request("GET", path, params=params)
-        return self._objector.objectify(data)
+        return self._objectify_request(method="GET", params=params, path=path)
 
     def info(
         self,
-        fullnames: Optional[Sequence[str]] = None,
+        fullnames: Optional[Iterable[str]] = None,
         url: Optional[str] = None,
     ) -> Generator[Union[Subreddit, Comment, Submission], None, None]:
         """Fetch information about each item in ``fullnames`` or from ``url``.
@@ -480,7 +515,7 @@ class Reddit:
                   different set of submissions.
 
         """
-        none_count = [fullnames, url].count(None)
+        none_count = (fullnames, url).count(None)
         if none_count > 1:
             raise TypeError("Either `fullnames` or `url` must be provided.")
         if none_count < 1:
@@ -512,6 +547,50 @@ class Reddit:
 
         return generator(url)
 
+    def _objectify_request(
+        self,
+        data: Optional[
+            Union[Dict[str, Union[str, Any]], bytes, IO, str]
+        ] = None,
+        files: Optional[Dict[str, IO]] = None,
+        method: str = "",
+        params: Optional[Union[str, Dict[str, str]]] = None,
+        path: str = "",
+    ) -> Any:
+        """Run a request through the ``Objector``.
+
+        :param data: Dictionary, bytes, or file-like object to send in the body
+            of the request (default: None).
+        :param files: Dictionary, filename to file (like) object mapping
+            (default: None).
+        :param method: The HTTP method (e.g., GET, POST, PUT, DELETE).
+        :param params: The query parameters to add to the request (default:
+            None).
+        :param path: The path to fetch.
+
+        """
+        return self._objector.objectify(
+            self.request(
+                data=data, files=files, method=method, params=params, path=path
+            )
+        )
+
+    def _handle_rate_limit(
+        self, exception: RedditAPIException
+    ) -> Optional[Union[int]]:
+        for item in exception.items:
+            if item.error_type == "RATELIMIT":
+                amount_search = self._ratelimit_regex.search(item.message)
+                if not amount_search:
+                    break
+                seconds = int(amount_search.group(1))
+                if "minute" in amount_search.group(2):
+                    seconds *= 60
+                if seconds <= int(self.config.ratelimit_seconds):
+                    sleep_seconds = seconds + min(seconds / 10, 1)
+                    return sleep_seconds
+        return None
+
     def patch(
         self,
         path: str,
@@ -526,8 +605,7 @@ class Reddit:
             of the request (default: None).
 
         """
-        data = self.request("PATCH", path, data=data)
-        return self._objector.objectify(data)
+        return self._objectify_request(data=data, method="PATCH", path=path)
 
     def post(
         self,
@@ -549,10 +627,32 @@ class Reddit:
             None).
 
         """
-        data = self.request(
-            "POST", path, data=data or {}, files=files, params=params
-        )
-        return self._objector.objectify(data)
+        data = data or {}
+        try:
+            return self._objectify_request(
+                data=data,
+                files=files,
+                method="POST",
+                params=params,
+                path=path,
+            )
+        except RedditAPIException as exception:
+            seconds = self._handle_rate_limit(exception=exception)
+            if seconds is not None:
+                logger.debug(
+                    "Rate limit hit, sleeping for {:.2f} seconds".format(
+                        seconds
+                    )
+                )
+                time.sleep(seconds)
+                return self._objectify_request(
+                    data=data,
+                    files=files,
+                    method="POST",
+                    params=params,
+                    path=path,
+                )
+            raise
 
     def put(
         self,
@@ -568,8 +668,7 @@ class Reddit:
             of the request (default: None).
 
         """
-        data = self.request("PUT", path, data=data)
-        return self._objector.objectify(data)
+        return self._objectify_request(data=data, method="PUT", path=path,)
 
     def random_subreddit(self, nsfw: bool = False) -> Subreddit:
         """Return a random lazy instance of :class:`~.Subreddit`.
@@ -623,9 +722,33 @@ class Reddit:
             (default: None).
 
         """
-        return self._core.request(
-            method, path, data=data, files=files, params=params
-        )
+        try:
+            return self._core.request(
+                method,
+                path,
+                data=data,
+                files=files,
+                params=params,
+                timeout=self.config.timeout,
+            )
+        except BadRequest as exception:
+            try:
+                data = exception.response.json()
+            except ValueError:
+                # TODO: Remove this exception after 2020-12-31 if no one has
+                # filed a bug against it.
+                raise Exception(
+                    "Unexpected BadRequest without json body. Please file a "
+                    "bug at https://github.com/praw-dev/praw/issues"
+                ) from exception
+            if "fields" in data:
+                assert len(data["fields"]) == 1
+                field = data["fields"][0]
+            else:
+                field = None
+            raise RedditAPIException(
+                [data["reason"], data["explanation"], field]
+            ) from exception
 
     def submission(  # pylint: disable=invalid-name,redefined-builtin
         self, id: Optional[str] = None, url: Optional[str] = None
